@@ -623,7 +623,7 @@ fn should_skip_file(file_name: &str, strict: bool) -> bool {
 /// - `tool_name`: Optional hint for finding non-executable files by name matching.
 ///   When provided, if no executable is found, will search for files matching the tool name
 ///   and make them executable before renaming.
-fn rename_executable_in_dir(
+pub fn rename_executable_in_dir(
     dir: &Path,
     new_name: &str,
     tool_name: Option<&str>,
