@@ -52,19 +52,43 @@ pub struct HookEnv {
 impl HookEnv {
     pub async fn run(self) -> Result<()> {
         let config = Config::get().await?;
-        let watch_files = config.watch_files().await?;
+        let ts = config.get_toolset().await?;
         time!("hook-env");
+
+        // Try to use cached watch_files for early exit check if env_cache is enabled
+        // This avoids executing plugins just to get watch_files
+        let watch_files = if Settings::get().env_cache {
+            if let Ok(Some(cached)) = ts.try_load_env_cache_full(&config) {
+                trace!("env_cache: using cached watch_files for early exit check");
+                cached
+                    .watch_files
+                    .iter()
+                    .map(|p| WatchFilePattern::from(p.as_path()))
+                    .collect()
+            } else {
+                config.watch_files().await?
+            }
+        } else {
+            config.watch_files().await?
+        };
+
         if !self.force && hook_env::should_exit_early(watch_files.clone(), self.reason) {
             trace!("should_exit_early true");
             return Ok(());
         }
         time!("should_exit_early false");
-        let ts = config.get_toolset().await?;
         let shell = get_shell(self.shell).expect("no shell provided, use `--shell=zsh`");
         miseprint!("{}", hook_env::clear_old_env(&*shell))?;
-        let (mut mise_env, env_results) = ts.final_env(&config).await?;
+
+        // Use env_with_path_and_split which handles caching internally
+        let (mut mise_env, user_paths, tool_paths) = ts.env_with_path_and_split(&config).await?;
         mise_env.remove(&*PATH_KEY);
-        self.display_status(&config, ts, &mise_env).await?;
+
+        // Create config_paths from user_paths for display_status and build_session
+        let config_paths: IndexSet<PathBuf> = user_paths.iter().cloned().collect();
+        self.display_status(&config, ts, &mise_env, &config_paths)
+            .await?;
+
         let mut diff = EnvDiff::new(&env::PRISTINE_ENV, mise_env.clone());
         let mut patches = diff.to_patches();
 
@@ -78,7 +102,6 @@ impl HookEnv {
             });
         }
 
-        let (user_paths, tool_paths) = ts.list_final_paths_split(&config, env_results).await?;
         // Combine paths for __MISE_DIFF tracking (all mise-managed paths)
         let all_paths: Vec<PathBuf> = user_paths
             .iter()
@@ -97,8 +120,15 @@ impl HookEnv {
         patches.extend(self.build_path_operations(&user_paths, &tool_paths, &__MISE_DIFF.path)?);
         patches.push(self.build_diff_operation(&diff)?);
         patches.push(
-            self.build_session_operation(&config, ts, mise_env, new_aliases.clone(), watch_files)
-                .await?,
+            self.build_session_operation(
+                &config,
+                ts,
+                mise_env,
+                new_aliases.clone(),
+                watch_files,
+                &config_paths,
+            )
+            .await?,
         );
 
         // Clear the precmd run flag after running once from precmd
@@ -128,6 +158,7 @@ impl HookEnv {
         config: &Arc<Config>,
         ts: &Toolset,
         cur_env: &EnvMap,
+        config_paths: &IndexSet<PathBuf>,
     ) -> Result<()> {
         if self.status || Settings::get().status.show_tools {
             let prev = &PREV_SESSION.loaded_tools;
@@ -163,14 +194,10 @@ impl HookEnv {
                 let env_diff = env_diff.into_iter().map(patch_to_status).join(" ");
                 info!("{}", truncate_str(&env_diff, TERM_WIDTH.max(60) - 5, "…"));
             }
-            let new_paths: IndexSet<PathBuf> = config
-                .path_dirs()
-                .await
-                .map(|p| p.iter().cloned().collect())
-                .unwrap_or_default();
+            // Use passed config_paths instead of calling config.path_dirs()
             let old_paths = &PREV_SESSION.config_paths;
-            let removed_paths = old_paths.difference(&new_paths).collect::<IndexSet<_>>();
-            let added_paths = new_paths.difference(old_paths).collect::<IndexSet<_>>();
+            let removed_paths = old_paths.difference(config_paths).collect::<IndexSet<_>>();
+            let added_paths = config_paths.difference(old_paths).collect::<IndexSet<_>>();
             if !added_paths.is_empty() {
                 let status = added_paths
                     .iter()
@@ -385,6 +412,7 @@ impl HookEnv {
         env: EnvMap,
         aliases: indexmap::IndexMap<String, String>,
         watch_files: BTreeSet<WatchFilePattern>,
+        config_paths: &IndexSet<PathBuf>,
     ) -> Result<EnvDiffOperation> {
         let loaded_tools = if self.status || Settings::get().status.show_tools {
             ts.list_current_versions()
@@ -394,8 +422,15 @@ impl HookEnv {
         } else {
             Default::default()
         };
-        let session =
-            hook_env::build_session(config, env, aliases, loaded_tools, watch_files).await?;
+        let session = hook_env::build_session(
+            config,
+            env,
+            aliases,
+            loaded_tools,
+            watch_files,
+            config_paths.clone(),
+        )
+        .await?;
         Ok(EnvDiffOperation::Add(
             "__MISE_SESSION".into(),
             hook_env::serialize(&session)?,
