@@ -184,6 +184,10 @@ impl TaskExecutor {
         if !self.timings {
             env.insert("MISE_TASK_TIMINGS".to_string(), "0".to_string());
         }
+        // Propagate MISE_ENV to child tasks so -E flag works for nested mise invocations
+        if !crate::env::MISE_ENV.is_empty() {
+            env.insert("MISE_ENV".to_string(), crate::env::MISE_ENV.join(","));
+        }
         if let Some(cwd) = &*crate::dirs::CWD {
             env.insert("MISE_ORIGINAL_CWD".into(), cwd.display().to_string());
         }
@@ -804,7 +808,13 @@ impl TaskExecutor {
         if !spec.cmd.args.is_empty() || !spec.cmd.flags.is_empty() {
             let args: Vec<String> = get_args();
             trace!("Parsing usage spec for {:?}", args);
-            let po = usage::parse(&spec, &args).map_err(|err| eyre!(err))?;
+            // Pass env vars to Parser so it can resolve env= defaults in usage specs
+            let env_map: std::collections::HashMap<String, String> =
+                env.iter().map(|(k, v)| (k.clone(), v.clone())).collect();
+            let po = usage::Parser::new(&spec)
+                .with_env(env_map)
+                .parse(&args)
+                .map_err(|err| eyre!(err))?;
             for (k, v) in po.as_env() {
                 trace!("Adding key {} value {} in env", k, v);
                 env.insert(k, v);
