@@ -1,9 +1,9 @@
 use crate::Result;
+use once_cell::sync::Lazy;
+use regex::Regex;
 use std::path::PathBuf;
 
 use async_trait::async_trait;
-use eyre::eyre;
-use regex::Regex;
 
 use crate::{
     dirs, env,
@@ -13,6 +13,14 @@ use crate::{
 
 use super::TaskFileProvider;
 
+static SSH_REGEX: Lazy<Regex> = Lazy::new(|| {
+    Regex::new(r"^git::(?P<url>ssh://((?P<user>[^@]+)@)(?P<host>[^/]+)/(?P<repo>.+)\.git)//(?P<path>[^?]+)(\?ref=(?P<branch>[^?]+))?$").unwrap()
+});
+
+static HTTPS_REGEX: Lazy<Regex> = Lazy::new(|| {
+    Regex::new(r"^git::(?P<url>https?://(?P<host>[^/]+)/(?P<repo>.+)\.git)//(?P<path>[^?]+)(\?ref=(?P<branch>[^?]+))?$").unwrap()
+});
+
 #[derive(Debug)]
 pub struct RemoteTaskGitBuilder {
     store_path: PathBuf,
@@ -77,61 +85,33 @@ impl RemoteTaskGit {
     }
 
     fn get_repo_structure(&self, file: &str) -> GitRepoStructure {
-        if self.detect_ssh(file).is_ok() {
-            return self.detect_ssh(file).unwrap();
+        if let Some(repo) = Self::parse_ssh(file) {
+            return repo;
         }
-        self.detect_https(file).unwrap()
+        Self::parse_https(file).unwrap()
     }
 
-    fn detect_ssh(&self, file: &str) -> Result<GitRepoStructure> {
-        let re = Regex::new(r"^git::(?P<url>ssh://((?P<user>[^@]+)@)(?P<host>[^/]+)/(?P<repo>.+)\.git)//(?P<path>[^?]+)(\?ref=(?P<branch>[^?]+))?$").unwrap();
-
-        if !re.is_match(file) {
-            return Err(eyre!("Invalid SSH URL"));
-        }
-
-        let captures = re.captures(file).unwrap();
-
+    fn parse_ssh(file: &str) -> Option<GitRepoStructure> {
+        let captures = SSH_REGEX.captures(file)?;
         let url_without_path = captures.name("url").unwrap().as_str();
-
         let path = captures.name("path").unwrap().as_str();
-
-        let branch: Option<String> = captures.name("branch").map(|m| m.as_str().to_string());
-
-        Ok(GitRepoStructure::new(url_without_path, path, branch))
+        let branch = captures.name("branch").map(|m| m.as_str().to_string());
+        Some(GitRepoStructure::new(url_without_path, path, branch))
     }
 
-    fn detect_https(&self, file: &str) -> Result<GitRepoStructure> {
-        let re = Regex::new(r"^git::(?P<url>https?://(?P<host>[^/]+)/(?P<repo>.+)\.git)//(?P<path>[^?]+)(\?ref=(?P<branch>[^?]+))?$").unwrap();
-
-        if !re.is_match(file) {
-            return Err(eyre!("Invalid HTTPS URL"));
-        }
-
-        let captures = re.captures(file).unwrap();
-
+    fn parse_https(file: &str) -> Option<GitRepoStructure> {
+        let captures = HTTPS_REGEX.captures(file)?;
         let url_without_path = captures.name("url").unwrap().as_str();
-
         let path = captures.name("path").unwrap().as_str();
-
-        let branch: Option<String> = captures.name("branch").map(|m| m.as_str().to_string());
-
-        Ok(GitRepoStructure::new(url_without_path, path, branch))
+        let branch = captures.name("branch").map(|m| m.as_str().to_string());
+        Some(GitRepoStructure::new(url_without_path, path, branch))
     }
 }
 
 #[async_trait]
 impl TaskFileProvider for RemoteTaskGit {
     fn is_match(&self, file: &str) -> bool {
-        if self.detect_ssh(file).is_ok() {
-            return true;
-        }
-
-        if self.detect_https(file).is_ok() {
-            return true;
-        }
-
-        false
+        SSH_REGEX.is_match(file) || HTTPS_REGEX.is_match(file)
     }
 
     async fn get_local_path(&self, file: &str) -> Result<PathBuf> {
@@ -182,9 +162,7 @@ mod tests {
     use super::*;
 
     #[test]
-    fn test_valid_detect_ssh() {
-        let remote_task_git = RemoteTaskGitBuilder::new().build();
-
+    fn test_valid_parse_ssh() {
         let test_cases = vec![
             "git::ssh://git@github.com/myorg/example.git//myfile?ref=v1.0.0",
             "git::ssh://git@github.com/myorg/example.git//terraform/myfile?ref=master",
@@ -194,15 +172,16 @@ mod tests {
         ];
 
         for url in test_cases {
-            let result = remote_task_git.detect_ssh(url);
-            assert!(result.is_ok());
+            assert!(
+                RemoteTaskGit::parse_ssh(url).is_some(),
+                "Failed for: {}",
+                url
+            );
         }
     }
 
     #[test]
-    fn test_invalid_detect_ssh() {
-        let remote_task_git = RemoteTaskGitBuilder::new().build();
-
+    fn test_invalid_parse_ssh() {
         let test_cases = vec![
             "git::ssh://myserver.com/example.git//myfile?ref=master",
             "git::ssh://user@myserver.com/example.git?ref=master",
@@ -211,15 +190,16 @@ mod tests {
         ];
 
         for url in test_cases {
-            let result = remote_task_git.detect_ssh(url);
-            assert!(result.is_err());
+            assert!(
+                RemoteTaskGit::parse_ssh(url).is_none(),
+                "Should fail for: {}",
+                url
+            );
         }
     }
 
     #[test]
-    fn test_valid_detect_https() {
-        let remote_task_git = RemoteTaskGitBuilder::new().build();
-
+    fn test_valid_parse_https() {
         let test_cases = vec![
             "git::https://github.com/myorg/example.git//myfile?ref=v1.0.0",
             "git::https://github.com/myorg/example.git//terraform/myfile?ref=master",
@@ -230,15 +210,16 @@ mod tests {
         ];
 
         for url in test_cases {
-            let result = remote_task_git.detect_https(url);
-            assert!(result.is_ok());
+            assert!(
+                RemoteTaskGit::parse_https(url).is_some(),
+                "Failed for: {}",
+                url
+            );
         }
     }
 
     #[test]
-    fn test_invalid_detect_https() {
-        let remote_task_git = RemoteTaskGitBuilder::new().build();
-
+    fn test_invalid_parse_https() {
         let test_cases = vec![
             "git::https://myserver.com/example.git?ref=master",
             "git::https://user@myserver.com/example.git",
@@ -246,15 +227,16 @@ mod tests {
         ];
 
         for url in test_cases {
-            let result = remote_task_git.detect_https(url);
-            assert!(result.is_err());
+            assert!(
+                RemoteTaskGit::parse_https(url).is_none(),
+                "Should fail for: {}",
+                url
+            );
         }
     }
 
     #[test]
     fn test_extract_ssh_url_information() {
-        let remote_task_git = RemoteTaskGitBuilder::new().build();
-
         let test_cases: Vec<(&str, &str, &str, Option<String>)> = vec![
             (
                 "git::ssh://git@github.com/myorg/example.git//myfile?ref=v1.0.0",
@@ -277,7 +259,7 @@ mod tests {
         ];
 
         for (url, expected_repo, expected_path, expected_branch) in test_cases {
-            let repo = remote_task_git.detect_ssh(url).unwrap();
+            let repo = RemoteTaskGit::parse_ssh(url).unwrap();
             assert_eq!(expected_repo, repo.url_without_path);
             assert_eq!(expected_path, repo.path);
             assert_eq!(expected_branch, repo.branch);
@@ -286,8 +268,6 @@ mod tests {
 
     #[test]
     fn test_extract_https_url_information() {
-        let remote_task_git = RemoteTaskGitBuilder::new().build();
-
         let test_cases: Vec<(&str, &str, &str, Option<String>)> = vec![
             (
                 "git::https://github.com/myorg/example.git//myfile?ref=v1.0.0",
@@ -310,7 +290,7 @@ mod tests {
         ];
 
         for (url, expected_repo, expected_path, expected_branch) in test_cases {
-            let repo = remote_task_git.detect_https(url).unwrap();
+            let repo = RemoteTaskGit::parse_https(url).unwrap();
             assert_eq!(expected_repo, repo.url_without_path);
             assert_eq!(expected_path, repo.path);
             assert_eq!(expected_branch, repo.branch);
@@ -345,8 +325,8 @@ mod tests {
         ];
 
         for (first_url, second_url, expected) in test_cases {
-            let first_repo = remote_task_git.detect_ssh(first_url).unwrap();
-            let second_repo = remote_task_git.detect_ssh(second_url).unwrap();
+            let first_repo = RemoteTaskGit::parse_ssh(first_url).unwrap();
+            let second_repo = RemoteTaskGit::parse_ssh(second_url).unwrap();
             let first_cache_key = remote_task_git.get_cache_key(&first_repo);
             let second_cache_key = remote_task_git.get_cache_key(&second_repo);
             assert_eq!(expected, first_cache_key == second_cache_key);
@@ -381,8 +361,8 @@ mod tests {
         ];
 
         for (first_url, second_url, expected) in test_cases {
-            let first_repo = remote_task_git.detect_https(first_url).unwrap();
-            let second_repo = remote_task_git.detect_https(second_url).unwrap();
+            let first_repo = RemoteTaskGit::parse_https(first_url).unwrap();
+            let second_repo = RemoteTaskGit::parse_https(second_url).unwrap();
             let first_cache_key = remote_task_git.get_cache_key(&first_repo);
             let second_cache_key = remote_task_git.get_cache_key(&second_repo);
             assert_eq!(expected, first_cache_key == second_cache_key);
